@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2017
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2022 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,30 +17,40 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 "Matern" <- function(d, range = 1, alpha = 1/range, 
     smoothness = 0.5, nu = smoothness, phi = 1.0) {
     #
     # Matern covariance function transcribed from Stein's book page 31
-    # nu==smoothness, alpha ==  1/range
+    # nu==smoothness, alpha ==  1/range == aRange 
     #
     # GeoR parameters map to kappa==smoothness and phi == range
     # check for negative distances
     # phi is accepted as the marginal variance of the process (see below)
-    # within fields, however, this parameter is "rho" and we recommend
+    # within fields, however, this parameter is sigma^2 and we recommend
     # not using phi.
-
     if (any(d < 0)) 
         stop("distance argument must be nonnegative")
+    # rescale distances
     d <- d * alpha
+    # call some special cases for half fractions of nu
+    if( nu ==.5){
+        return( phi*exp( -d) )
+    }
+     if( nu ==1.5){
+         return( phi*(1+d)*exp( -d) )
+     }
+     if( nu ==2.5){
+         return( phi*(1+d+d^2/3)*exp( -d) )
+     }
+    # otherwise .....
+    # call to  Bessel function from R base package                                  #
     # avoid sending exact zeroes to besselK
     d[d == 0] <- 1e-10
     #
     # the hairy constant ...
     con <- (2^(nu - 1)) * gamma(nu)
     con <- 1/con
-    #
-    # call to  Bessel function from R base package
-    #
     return(phi * con * (d^nu) * besselK(d, nu))
 }
