@@ -1,7 +1,7 @@
 #
 # fields  is a package for analysis of spatial data written for
 # the R software environment.
-# Copyright (C) 2021 Colorado School of Mines
+# Copyright (C) 2022 Colorado School of Mines
 # 1500 Illinois St., Golden, CO 80401
 # Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
@@ -26,13 +26,21 @@
     #
     M <- length(grid.list)
     gcounts <- unlist(lapply(grid.list, FUN = length))
-    xy <- (1:M)[gcounts > 1]
+    
+    xy <- (1:M)[(gcounts > 1)]
+    
+    if( length(xy) ==1){
+       xy<- sort( c(xy,  which(gcounts == 1 ) ) )
+    }
+    
+    
     if (length(xy) > 2) {
         stop("only two components of the grid list\ncan have more than one element")
     }
+    
     #
-    # swap the roles of x and y
-    if (order.variables == "yx") {
+    # swap the roles of x and y for 2D grid
+    if (order.variables == "yx" & (M!=1) ) {
         xy <- xy[2:1]
     }
     #
