@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2022 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 "predictSEUsingKrigA" <- function(object, x = NULL, cov = FALSE, 
     verbose = FALSE, ...) {
     #
@@ -50,8 +51,8 @@
     }
     # Default is to use parameters in best.model
     lambda <- object$best.model[1]
-    rho <- object$best.model[3]
-    sigma2 <- object$best.model[2]
+    sigma <- object$best.model[3]
+    tau2 <- object$best.model[2]
     nx <- nrow(xM)
     wght.vec <- t(Krig.Amatrix(object, xraw, lambda, ...))
     if (verbose) {
@@ -68,14 +69,14 @@
     Wi <- Krig.make.Wi(object)$Wi
     # find covariance of data
     if (object$nondiag.W) {
-        Cov.y <- rho * do.call(call.name, c(object$args, list(x1 = xM, 
-            x2 = xM))) + sigma2 * Wi
+        Cov.y <- sigma * do.call(call.name, c(object$args, list(x1 = xM, 
+            x2 = xM))) + tau2 * Wi
     }
     else {
         #     this is one case where keeping diagonal
         #     matrix as a vector will not work.
-        Cov.y <- rho * do.call(call.name, c(object$args, list(x1 = xM, 
-            x2 = xM))) + sigma2 * diag(Wi)
+        Cov.y <- sigma * do.call(call.name, c(object$args, list(x1 = xM, 
+            x2 = xM))) + tau2 * diag(Wi)
     }
     if (!cov) {
         # find diagonal elements of covariance matrix
@@ -84,7 +85,7 @@
         # diagonal elements of the full
         #  prediction covariance matrix.
         #
-        temp1 <- rho * colSums(wght.vec * do.call(call.name, 
+        temp1 <- sigma * colSums(wght.vec * do.call(call.name, 
             c(object$args, list(x1 = xM, x2 = x))))
         temp2 <- colSums(wght.vec * (Cov.y %*% wght.vec))
         #
@@ -93,7 +94,7 @@
         # as radial basis functions (RBFs) temp0 should be zero.
         # Positivity results from the generalized divided difference
         # properties of RBFs.
-        temp0 <- rho * do.call(call.name, c(object$args, list(x1 = x, 
+        temp0 <- sigma * do.call(call.name, c(object$args, list(x1 = x, 
             marginal = TRUE)))
         #
         temp <- temp0 - 2 * temp1 + temp2
@@ -104,12 +105,12 @@
         #
         # find full covariance matrix
         #
-        temp1 <- rho * t(wght.vec) %*% do.call(call.name, c(object$args, 
+        temp1 <- sigma * t(wght.vec) %*% do.call(call.name, c(object$args, 
             list(x1 = xM, x2 = x)))
         #
         temp2 <- t(wght.vec) %*% Cov.y %*% wght.vec
         #
-        temp0 <- rho * do.call(call.name, c(object$args, list(x1 = x, 
+        temp0 <- sigma * do.call(call.name, c(object$args, list(x1 = x, 
             x2 = x)))
         #
         temp <- temp0 - t(temp1) - temp1 + temp2
