@@ -1,7 +1,7 @@
 #
 # fields  is a package for analysis of spatial data written for
 # the R software environment.
-# Copyright (C) 2021 Colorado School of Mines
+# Copyright (C) 2022 Colorado School of Mines
 # 1500 Illinois St., Golden, CO 80401
 # Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
@@ -20,7 +20,9 @@
 # or see http://www.r-project.org/Licenses/GPL-2
 ##END HEADER
 stationary.image.cov <- function(ind1, ind2, Y, cov.obj = NULL, 
-    setup = FALSE, grid, M = NULL, N = NULL, cov.function="stationary.cov",delta=NULL, cov.args=NULL, ...) {
+    setup = FALSE, grid, M = NULL, N = NULL, 
+    cov.function="stationary.cov",delta=NULL, 
+    cov.args=NULL, ...) {
     #
     # if cov object is missing then create
     # basically need to enlarge domain and find the FFT of the
